
$TITLE Guizhou village model - Version Guimod 1.01
$OFFUPPER

$ontext
Date: 25 March, 2011
Author: Ulrich Kleinwechter
Agricultural and Food Policy Group, University of Hohenheim

Copyright 2011 Ulrich Kleinwechter.

This file is part of Guimod 1.01.

Guimod is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Guimod is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Guimod.  If not, see <http://www.gnu.org/licenses/>.
$offtext

$ontext
######### OUTLINE OF THE PROGRAMME ############

1. MODEL DESCRIPTION

2. MODEL ORIGINS

3. PARAMETER LISTING

4. VARIABLE LISTING

5. SET DECLARATION

6. PARAMETER DECLARATION

7. DATA ENTRY

8. PARAMETER ASSIGNMENT

9. VARIABLE DECLARATION

10. VARIABLE INITIALISATION

11. EQUATIONS DECLARATION

12. EQUATIONS DEFINITION

13. MODEL CLOSURE

14. MODEL & SOLVE STATEMENTS

15. CALIBRATION CHECK

16. SIMULATIONS

$offtext

*################ 1. MODEL DESCRIPTION #####################
$ontext
This is the Guizhou village model as used for the policy simulations carried out
in the scope of the dissertation
Kleinwechter, U. (2011), Village Level Impacts of Trade Reform in China.
Dissertation, University of Hohenheim. (enclosed to this program)

The model has 6 households, 5 consumption goods, 4 activities + blood sales and
2 factors (land and labor), 3 intermediate inputs (excl. village labor).
Furthermore, the model features the possibility to choose between two land market
closures (land nontradable at the household level or a village land rental market)
and two calibration schemes for the migration behaviour of the households (equal
and different own-wage responses in migration).
$offtext

*################ 2. MODEL ORIGINS ###########################################
$ontext
The model is developed in the tradition of the village equilibrium models by
Taylor and Adelman (1996) and Kuiper (2005). The theoretical model of household
behaviour underlying the model draws on works by Lopez(1984, 1986), Sonoda (2008)
and Wouterse (2006) (see Kleinwechter, 2011).

The notation used in this code as well as the structure of the code follows the
GLOBE global CGE model by McDonald et al. (2007) and the IFPRI standard model by
Loefgren et al. (2002).

Code for the modelling of Cobb-Douglas activities is adapted from the IFPRI
standard model (Loefgren et al., 2002).

The calculation of welfare measures follows McDonald et al. (2007).

References:

Kleinwechter, U. (2011), Village Level Impacts of Trade Reform in China.
         Dissertation, University of Hohenheim.

Kuiper, M. (2005), Village Modeling - A Chinese Recipe for Blending General
         Equilibrium and Household Modeling. Dissertation, Wageningen University.

Loefgren, H., Lee Harris, R. and Robinson, S. (2002), A Standard Computable
         General Equilibrium (CGE) Model in GAMS. Microcomputers in Policy
         Research Series No. 5, International Food Policy Research Institute,
         Washington D.C.

Lopez, R. (1984), Estimating Labour Supply and Production Decisions of Self-
         Employed Farm Producers. European Economic Review, 24, 61-82.

Lopez, R. (1986), Stuructural Models of the Farm Household that Allow for
         Interdependent Utility and Profit-Maximization Decisions.
         In: Singh, I., Squire, L. and J. Strauss (ed.), Agricultural Household
         Models: Applications and Policy. The Johns Hopkins University Press.
         Chapter 11, 306-325.

McDonald, S., Thierfelder, K. and Robinson, S. (2007), GLOBE: A SAM Based Global
         CGE Model using GTAP Data. Model Documentation, University of Sheffield.

Sonoda, T. (2008), A System Comparison Approach to Distinguish two Nonseparable
         and Nonnested Agricultural Household Models. American Journal of
         Agricultural Economics, 90, 509-523.

Taylor, J. and Adelman, I. (ed.) (1996), Village Economies - The Design,
         Estimation, and Use of Villagewide Economic Models.
         Cambridge University Press.

Wouterse, F. (2006), Survival or Accumulation - Migration and Rural Households
         in Burkina Faso. Dissertation, Wageningen University.
$offtext

*################## 3. PARAMETER LISTING #######################################
$ontext
 alpha(A,H)              Efficiency parameter in CD production function
 beta(F,A,H)             Share parameter of CD production function
 delta(A,H)              Exponent for labor in activity a in labor utility
                         function
 epsilon(A,H)            Shift parameter in labor utility function
 FDC0(F,A,H)             Demand for factor f by CD activity a in household h
 FDD0(F,A,H)             Demand for factor f by off-farm work activity a in household h
 FSH0(F,H)               Household endowment with factor F
 FSHM0(F)                Endowment of migrated household with factor F
 gamma(C,H)              Share parameter of Stone-Geary utility function
 hactive(H)              Number of economically active members in household
 hdeps(H)                Number of dependants in household
 hdepscal                Scaling factor for dependants in household
 hexpgift(H)             Household expenditure on gifts
 hexpshock(H)            Household expenditure because of shocks
 hexpsi(H)               Savings of household h
 hobloodconst(H)         Income of household h from blood sales
 hoexpconssh(H)          Expenditure share on construction of household h
 hogiftconst(H)          Income of household h from gifts
 hogovconst(H)           Income of household h from government transfers
 hosiconst(H)            Income of household h from savings
 hoshoconst(H)           Income of household h from shocks
 HEXPC0(H)               Consumption expenditure of household h
 HEXPCONS0(H)            Expenditure of household h on construction
 HEXPCP0(H)              Per-capita consumption expenditure of household h
 HS0(H)                  Number of persons living in the household
 ica(C,A,H)              Share of intermediate input commodity c in quantity of aggregate input in activity a by household h
 ielast(C,H)             Income elasticity of household h for commodity c
 inta(A,H)               Leontief Parameter for demand for aggregate intermediate input by CD activity a
 ioqqqa(A,C,H)           Share of commodity c in output by activity a
 ivash(A,H)              Value-added coefficient of C-D activity a of household h
 kappa(H)                Share parameter of remittances function of household a in migr. activity
 lambda(H)               Marginal utility of income of household h (constant over all activities)
 PA0(A,H)                Price of activity a to household h
 PVA0(A,H)               Value-added price of activity a to household h
 pcscal(H)               A parameter to scale household per capita consumption in the labor demand function for migration
 PD0(C,H)                Consumer price of commodity c to household h
 PI0(C,H)                Price of intermediate input c to household h
 PIA0(A,H)               Aggregate price of intermediate input in activity a of household h
 QA0(A,H)                Output of activity a in household h
 QD0(C,H)                Per capita demand of household h for commodity c
 QDT0(C,H)               Total demand of household h for commodity c
 QINT0(A,C,H)            Demand of activity a in household h for intermediate commodity c
 QINTA0(A,H)             Aggregate demand of activity a in household h for intermediate commodity c
 QP0(C,H)                Quantity of commodity purchased by household h
 QQ0(C,H)                Quantity of commodity c produced by household h
 QR0(C,H)                Net quantity of village traded commodity c rented by household h
 QRM0(C)                 Net quantity of village traded commodity c rented by migrated household
 QS0(C,H)                Quantity of commodity c sold by household h
 QVA0(A,H)               Quantity of value-added of C-D activity a of household h
 QVM0(C)                 Quantity of commodity c imported into the village
 QVX0(C)                 Quantity of commodity c exported out of the village
 sigma(C,H)              Per capita subsistence consumption quantity of commodity c by household h
 tp                      Time period covered by the model (same unit as FDD)
 WALRAS0(H)              Slack variables
 WF0(FD,H)               Price for factor f in household h
 WFV0                    Village market price for land
 YH0(H)                  Total income of household h
 YR0(H)                  Remittance income of household h
 YT0                     Total income of all households
$offtext

*################# 4. VARIABLE LISTING #########################################
$ontext

 FDC(F,A,H)      Demand for factor f by CD activity a in household h
 FDD(F,A,H)      Demand for factor f by off-farm work activity a in household h
 FSH(F,H)        Household endowment with factor F
 HEXPC(H)        Consumption expenditure of household h
 HEXPCONS(H)     Expenditure of household h on construction
 HEXPCP(H)       Per-capita consumption expenditure of household h
 HS(H)           Number of persons living in the household
 PA(A,H)         Price of activity a to household h
 PVA(A,H)        Value-added price of activity a to household h
 PD(C,H)         Consumer price of commodity c to household h
 PI(C,H)         Price of intermediate input c to household h
 PIA(A,H)        Aggregate price of intermediate input in activity a of household h
 QA(A,H)         Output of activity a in household h
 QD(C,H)         Per capita demand of household h for commodity c
 QDT(C,H)        Total demand of household h for commodity c
 QINT(A,C,H)     Demand of activity a in household h for intermediate commodity c
 QINTA(A,H)      Aggregate demand of activity a in household h for intermediate commodity c
 QP(C,H)         Net quantity of commodity purchased by household h
 QQ(C,H)         Net quantity of commodity c produced by household h
 QR(C,H)         Net quantity of village traded commodity c rented by household h
 QRM(C)          Net quantity of village traded commodity c rented by migrated household
 QS(C,H)         Quantity of commodity c sold by household h
 QVA(C,H)        Quantity of value-added of C-D activity a of household h
 QVM(C)          Quantity of commodity c imported into the village
 QVX(C)          Quantity of commodity c exported out of the village
 WALRAS(H)       Slack variables
 WF(FD,A,H)      Price for factor f in activity a in household h
 WFV             Village market price for land
 YH(H)           Total income of household h
 YR(H)           Remittance income of household h
 YT              Total income of all households
$offtext

*#################### 5. SET DECLARATION #######################################

 SETS
*## Declare set for SAM accounts
  SAC            SAM accounts
*# Declare sets for activities
  A(SAC)         All activities
  AC(A)          Cobb-Douglas activities
  AO(A)          Off-farm work activities
  AOM(A)         Migration activities
  AOL(A)         Local off-farm activities
  AOF(A)         Formal local off-farm activities
  AOI(A)         Informal local off-farm activities
* Declare sets for household specific activities
  HALMHI(A)        Activities of low migration high income household
  HALMMD(A)        Activities of low migration middle household
  HALMLO(A)        Activities of low migration low household
  HAHMHI(A)        Activities of high migration high income household
  HAHMMD(A)        Activities of high migration middle income household
  HAHMLO(A)        Activities of high migration low income household
*# Declare sets for commodities
  C              All commodities
  CI(C)          Intermediate input commodities
  CQ(C)          Commodities produced by households
  CD(C)          Commodities consumed by households
  CM(C)          Commodities traded by households on the market
  CP(C)          Commodities consumed & purchased by households
  CN(C)          Nontraded commodities consumed by households
  CS(CQ)         Commodities produced & sold but not consumed by households
  CVNT(C)        Village nontraded commodities
  CVX(C)         Village exported commodities
  CVM(C)         Village imported commodities
*# Declare sets for factors
  F(SAC)         Factors
  FU(F)          Utility factors
  FN(F)          Non-utility factors
*# Declare set for households
  H(SAC)         Households
*# Declare sets to map activities to households
  HA(H,A)        Mapping of activities to households
  HAC(H,A)       Mapping of Cobb-Douglas activities to households
  HAO(H,A)       Mapping of off-farm activities to households
  HAOL(H,A)      Mapping of local off-farm activities to households
  HAOF(H,A)      Mapping of formal local off-farm activities to households
  HAOI(H,A)      Mapping of informal local off-farm activities to households
  HAOM(H,A)      Mapping of migration activities to households
 ;

 ALIAS (A,AA) ;
 ALIAS (F,FF) ;
 ALIAS (C,CC) ;
 ALIAS (CD,CDD) ;
 ALIAS (SAC,SACC) ;

*################### 6. PARAMETER DECLARATION #################################

 PARAMETERS
*##### PARAMETERS USED IN EQUATIONS #######

*### Parameters associated with production and factor demand functions
  alpha(A,H)              Efficiency parameter in CD production function
  beta(F,A,H)             Share parameter of CD production function
  delta(A,H)              Exponent for labor in activity a in labor utility function
  epsilon(A,H)            Shift parameter for labor in activity a in labor utility function
  ica(C,A,H)              Share of intermediate input commodity c in quantity of aggregate input in activity a by household h
  inta(A,H)               Leontief Parameter for demand for aggregate intermediate input by CD activity a
  ioqqqa(A,C,H)           Share of commodity c in output by activity a of household h
  ivash(A,H)              Value-added coefficient of C-D activity a of household h
  lambda(H)               Marginal utility of income of household h (constant over all activities)
  pcscal(H)               A parameter to scale household per capita consumption in the labor demand function for migration
*### Parameters used in consumption demand  and income functions
  gamma(C,H)              Share parameter of Stone-Geary utility function
  hexpgift(H)             Household expenditure on gifts
  hexpshock(H)            Household expenditure associated with shocks
  hexpsi(h)               Savings of household h
  hobloodconst(H)         Income of household h from blood sales
  hoexpconssh(H)          Expenditure share on construction of household h
  hogiftconst(H)          Income of household h from gifts
  hogovconst(H)           Income of household h from government transfers
  hosiconst(H)            Income of household h from savings
  hoshoconst(H)           Income of household h from shocks
  ielast(C,H)             Income elasticity of household h for commodity c
  kappa(H)                Share parameter of remittances function of household a in migr. activity
  sigma(C,H)              Per capita subsistence consumption quantity of commodity c by household h
* ### Parameters used for the calculation of the number of consumers in household
  hactive(H)              Number of economically active members in household
  hdeps(H)                Number of dependants in household
  hdepscal                Scaling factor for dependants in household
  tp                      Time period covered by the model

*##### PARAMETERS USED FOR CALIBRATION #######

*### Prices
  PA0(A,H)                Price of activity a to household h
  PD0(C,H)                Consumer price of commodity c to household h
  PI0(C,H)                Price of intermediate input c to household h
  PIA0(A,H)               Aggregate price of intermediate input in activity a of household h
  PVA0(A,H)               Value-added price of activity a of household h
  WF0(F,H)                Price of factor f in household h
  WFV0                    Village market land rental price
*### Quantities
  FDC0(F,A,H)             Demand for factor f by CD activity a in household h
  FDD0(F,A,H)             Demand for factor f by off-farm work activity a in household h
  FSH0(F,H)               Household endowment with factor f
  FSHM0(F)                Endowment of migrated household with factor f
  QA0(A,H)                Output of activity a in household h
  QD0(C,H)                Per capita demand of household h for commodity c
  QDT0(C,H)               Total demand of household h for commodity c
  QINT0(A,C,H)            Demand of activity a in household h for intermediate commodity c
  QINTA0(A,H)             Aggregate demand of activity a in household h for intermediate commodity c
  QP0(C,H)                Quantity of commodity purchased by household h
  QR0(C,H)                Net quantity of village traded commodity c rented by household h
  QRM0(C)                 Net quantity of village traded commodity c rented by migrated household
  QQ0(C,H)                Quantity of commodity c produced by household h
  QS0(C,H)                Quantity of commodity c sold by household h
  QVA0(A,H)               Quantity of value-added of C-D activity a of household h
  QVM0(C)                 Quantity of commodity c imported into the village
  QVX0(C)                 Quantity of commodity c exported out of the village
*### Household size
  HS0(H)                  Number of persons living in the household
*### Household income and expenditure
  HEXPC0(H)               Consumption expenditure of household h
  HEXPCONS0(H)            Expenditure of household h on construction
  HEXPCP0(H)              Per-capita consumption expenditure of household h
  YH0(H)                  Total income of household h
  YR0(H)                  Remittance income of household h
  YT0                     Total income of all households
*### Slack variables
  WALRAS0(H)              "One slack variable for each of the households' income constraints"
 ;

*############## 7. DATA ENTRY ##################################################

$ontext
Data are imported from an excel file guimod1.01_data.xls which contains information
on sets, the village SAM, income elasticities and the delta and lambda parameters.
$offtext

*# Convert data from xls to gdx

$CALL "GDXXRW i=guimod1.01_data.xls o=data_in.gdx index=Layout!A4"

*# Read sets

$GDXIN data_in.gdx

$LOAD SAC
$LOAD C CI CQ CD CM CP CN CS CVNT CVX CVM
$LOAD A AC AO AOM AOL AOF AOI
$LOAD F FU FN
$LOAD H
$LOAD HALMHI HALMMD HALMLO HAHMHI HAHMMD HAHMLO

$GDXIN

*# Map activities to households

 HA("HLMHI",A)$(HALMHI(A))                = YES ;
 HA("HLMMD",A)$(HALMMD(A))                = YES ;
 HA("HLMLO",A)$(HALMLO(A))                = YES ;
 HA("HHMHI",A)$(HAHMHI(A))                = YES ;
 HA("HHMMD",A)$(HAHMMD(A))                = YES ;
 HA("HHMLO",A)$(HAHMLO(A))                = YES ;
 HAC("HLMHI",A)$(HALMHI(A) AND AC(A))     = YES ;
 HAC("HLMMD",A)$(HALMMD(A) AND AC(A))     = YES ;
 HAC("HLMLO",A)$(HALMLO(A) AND AC(A))     = YES ;
 HAC("HHMHI",A)$(HAHMHI(A) AND AC(A))     = YES ;
 HAC("HHMMD",A)$(HAHMMD(A) AND AC(A))     = YES ;
 HAC("HHMLO",A)$(HAHMLO(A) AND AC(A))     = YES ;
 HAO("HLMHI",A)$(HALMHI(A) AND AO(A))     = YES ;
 HAO("HLMMD",A)$(HALMMD(A) AND AO(A))     = YES ;
 HAO("HLMLO",A)$(HALMLO(A) AND AO(A))     = YES ;
 HAO("HHMHI",A)$(HAHMHI(A) AND AO(A))     = YES ;
 HAO("HHMMD",A)$(HAHMMD(A) AND AO(A))     = YES ;
 HAO("HHMLO",A)$(HAHMLO(A) AND AO(A))     = YES ;
 HAOL("HLMHI",A)$(HALMHI(A) AND AOL(A))   = YES ;
 HAOL("HLMMD",A)$(HALMMD(A) AND AOL(A))   = YES ;
 HAOL("HLMLO",A)$(HALMLO(A) AND AOL(A))   = YES ;
 HAOL("HHMHI",A)$(HAHMHI(A) AND AOL(A))   = YES ;
 HAOL("HHMMD",A)$(HAHMMD(A) AND AOL(A))   = YES ;
 HAOL("HHMLO",A)$(HAHMLO(A) AND AOL(A))   = YES ;
 HAOF("HLMHI",A)$(HALMHI(A) AND AOF(A))   = YES ;
 HAOF("HLMMD",A)$(HALMMD(A) AND AOF(A))   = YES ;
 HAOF("HLMLO",A)$(HALMLO(A) AND AOF(A))   = YES ;
 HAOF("HHMHI",A)$(HAHMHI(A) AND AOF(A))   = YES ;
 HAOF("HHMMD",A)$(HAHMMD(A) AND AOF(A))   = YES ;
 HAOF("HHMLO",A)$(HAHMLO(A) AND AOF(A))   = YES ;
 HAOI("HLMHI",A)$(HALMHI(A) AND AOI(A))   = YES ;
 HAOI("HLMMD",A)$(HALMMD(A) AND AOI(A))   = YES ;
 HAOI("HLMLO",A)$(HALMLO(A) AND AOI(A))   = YES ;
 HAOI("HHMHI",A)$(HAHMHI(A) AND AOI(A))   = YES ;
 HAOI("HHMMD",A)$(HAHMMD(A) AND AOI(A))   = YES ;
 HAOI("HHMLO",A)$(HAHMLO(A) AND AOI(A))   = YES ;
 HAOM("HLMHI",A)$(HALMHI(A) AND AOM(A))   = YES ;
 HAOM("HLMMD",A)$(HALMMD(A) AND AOM(A))   = YES ;
 HAOM("HLMLO",A)$(HALMLO(A) AND AOM(A))   = YES ;
 HAOM("HHMHI",A)$(HAHMHI(A) AND AOM(A))   = YES ;
 HAOM("HHMMD",A)$(HAHMMD(A) AND AOM(A))   = YES ;
 HAOM("HHMLO",A)$(HAHMLO(A) AND AOM(A))   = YES ;

 DISPLAY SAC,
         C, CI, CQ, CD, CM, CP, CN, CS, CVNT, CVX, CVM,
         A, AC, AO, AOM, AOL,
         F, FU, FN,
         H,
         HALMHI, HALMMD, HALMLO, HAHMHI, HAHMMD, HAHMLO,
         HA, HAC, HAO, HAOL, HAOF, HAOI, HAOM ;

*# Read SAM

 PARAMETER SAM1(SAC,SACC) ;

$GDXIN data_in.gdx

$LOAD SAM1

$GDXIN

* Scale original SAM to facilitate optimization:

 PARAMETER SAM(SAC,SACC);

 SAM(SAC,SACC) = SAM1(SAC,SACC)/1000 ;

 DISPLAY SAM1, SAM ;

* Read income elasticies, delta and lambda parameters and pcscal
$GDXIN data_in.gdx

$LOAD ielast, delta, lambda, pcscal

$GDXIN

DISPLAY ielast, delta, lambda, pcscal;

*############## 8. PARAMETER ASSIGNMENT ########################################

*#### Prices
$ontext
Due to the simple price relationsips in the model most prices can be simply
normalized to 1. Exceptions are the activity prices for off-farm work and
migration, i.e. the wage rates in the respective activities, as well as the
shadow prices for land and labor.
$offtext

*### Prices

* Output prices for activity (Will be overwritten for "AMIG", "AOFFF" and "AOFFI")
  PA0(A,H)$HA(H,A)        = 1 ;
* Prices of consumed commodities (Will be overwritten for CLEIS to make sure that
* it is equal to the household shadow wage
  PD0(C,H)$CD(C)          = 1 ;

* Factor prices
  WF0(F,H)        = 1 ;
  WFV0            = 1 ;
* Price for leisure
  PD0("CLEIS",H)          = WF0("FLAB",H) ;

*### PRICES OF OFF-FARM ACTIVITIES ##(wage rates in local off-farm and migration)

* Calculate household specific wage rates for local off-farm work
  PA0(A,H)$(HAOL(H,A) AND SAM("FLAB",A))  = SAM(A,"OUTVILL")/(SAM("FLAB",A)/WF0("FLAB",H)) ;
  PA0(A,H)$(HAOL(H,A) AND SAM("FLAB",A) eq 0)  = 0   ;

* Assume equal wage rates in migration (implies different values of kappa(H) (see below)
  PA0(A,H)$HAOM(H,A)     = 35 ;

* Prices for intermediate inputs
  PI0(C,H)$CI(C)          = 1;

  QINT0(A,"CINPCAP",H)$HAC(H,A)   = SAM("CINPCAP",A)/PI0("CINPCAP",H);
  QINT0(A,"CINPLAB",H)$HAC(H,A)   = SAM("CINPLAB",A)/PI0("CINPLAB",H);
  QINT0(A,"CSERVICES",H)$HAC(H,A) = SAM("CSERVICES",A)/PI0("CSERVICES",H);

  QINTA0(A,H) = SUM(C,QINT0(A,C,H)) ;

  ica(C,A,H)$(HAC(H,A) AND CI(C))  =  QINT0(A,C,H) / QINTA0(A,H) ;

  PIA0(A,H) = SUM(C, PI0(C,H) * ica(C,A,H)) ;

* Value-added price of CD activities

 Set  CQS(SAC)          SAM commodities produced by households   /cagr / ;

   PVA0(A,H)$HAC(H,A) = (SUM(CQS,SAM(A,CQS)) - QINTA0(A,H)*PIA0(A,H)) / (SUM(CQS,SAM(A,CQS))/PA0(A,H) -  QINTA0(A,H)/PIA0(A,H)) ;

*##### ASSIGNMENT OF EXOGENOUSLY GIVEN PARAMETERS ##################

* ### Parameters used for the calculation of the number of consumers in household (calculated in R with file 'hsizeCGE.r')

  hactive("HLMHI")  =      91  ;
  hactive("HLMMD")  =      68  ;
  hactive("HLMLO")  =      95  ;
  hactive("HHMHI")  =     178  ;
  hactive("HHMMD")  =     193  ;
  hactive("HHMLO")  =     122  ;

  hdeps("HLMHI")    =     122  ;
  hdeps("HLMMD")    =     186  ;
  hdeps("HLMLO")    =     162  ;
  hdeps("HHMHI")    =      44  ;
  hdeps("HHMMD")    =      62  ;
  hdeps("HHMLO")    =      38  ;

  hdepscal      =    0.5 ;

* Survey period: 1 year = 365 days
  tp            =    365 ;

*### Other parameters

* kappa(h)     -> see below
* lambda(h)    -> see below
* delta(f,a,h) -> see below


*##### ASSIGNMENT OF PARAMETERS FROM READ IN DATA ##############

*### QUANTITIES ###

* Intermediate demand as in SAM

*  QINT0(A,C,H)  -> see above
*  QINTA0(A,H)   -> see above

* Output by activity a of household h as in SAM

  QA0(A,H)$HAC(H,A)  = SUM(CQS,SAM(A,CQS))/PA0(A,H);
  QA0(A,H)$HAO(H,A)  = SAM("FLAB",A)/WF0("FLAB",H) ;
  QVA0(A,H)$HAC(H,A) = QA0(A,H)-QINTA0(A,H) ;

*# Declare a set to map commodities into activities
   Sets CAMAP(C,A) "Mapping of commodities into activities (used only for calibration)" /
      cagr.(aagrlmhi,aagrlmmd,aagrlmlo,aagrhmhi,aagrhmmd,aagrhmlo)
      cofff.(aoffflmhi,aoffflmmd,aoffflmlo,aofffhmhi,aofffhmmd,aofffhmlo)
      coffi.(aoffilmhi,aoffilmmd,aoffilmlo,aoffihmhi,aoffihmmd,aoffihmlo)
      cmig.(amiglmhi,amiglmmd,amiglmlo,amighmhi,amighmmd,amighmlo)/;

* Shares of commodities c in output by activity a
  ioqqqa(A,C,H)                 =  0   ;
  ioqqqa(A,C,H)$(HA(H,A) AND CAMAP(C,A))  =  1   ;
  QQ0(C,H) = SUM(A,ioqqqa(A,C,H) * QA0(A,H)) ;

* Supply of factor f (factor endowment)
  FSH0(F,H) = SAM(H,F)/WF0(F,H);

* Demand for factor f by activity a in household h
  FDC0(F,A,H)$(HAC(H,A) AND FU(F)) =  SAM(F,A)/WF0(F,H) ;
  FDC0(F,A,H)$(HAC(H,A) AND FN(F)) =  SAM(F,A)/WF0(F,H) + SAM("CLND",A)/WF0(F,H) ;
  FDD0(F,A,H)$HAO(H,A) = SAM(F,A)/WF0(F,H) ;

* Net land rentals of households
  QR0("CLND",H)   = FSH0("FLND",H) - SUM(A,FDC0("FLND",A,H))  ;
  QRM0(CVNT)      = - SUM(H,QR0("CLND",H));

* Supply of land by migrated household
  FSHM0("FLND")  = QRM0("CLND") ;

* Number of consumers in household
  HS0(H)         =   hactive(H) - SUM(HAOM(H,A),FDD0("FLAB",A,H))/tp + hdepscal * hdeps(H) ;

*### Household income and expenditure

  hexpgift(H)         =  SAM("TRGIFT",H) ;
  hexpshock(H)        =  SAM("TRSHOCK",H) ;
  hexpsi(H)           =  SAM("SISI",H) ;
  HEXPC0(H)           =  SAM("TOTAL",H) - SAM("SICONS",H) - hexpgift(H) - hexpshock(H) - hexpsi(H) ;
  HEXPCP0(H)          =  HEXPC0(H) / HS0(H) ;
  HEXPCONS0(H)        =  SAM("SICONS",H) ;

  hobloodconst("HLMHI") =  SAM("HLMHI","ABLOODLMHI") ;
  hobloodconst("HLMMD") =  SAM("HLMMD","ABLOODLMMD") ;
  hobloodconst("HLMLO") =  SAM("HLMLO","ABLOODLMLO") ;
  hobloodconst("HHMHI") =  SAM("HHMHI","ABLOODHMHI") ;
  hobloodconst("HHMMD") =  SAM("HHMMD","ABLOODHMMD") ;
  hobloodconst("HHMLO") =  SAM("HHMLO","ABLOODHMLO") ;
  hogiftconst(H)        =  SAM(H,"TRGIFT") ;
  hogovconst(H)         =  SAM(H,"GOV") ;
  hoshoconst(H)         =  SAM(H,"TRSHOCK") ;
  hosiconst(H)          =  SAM(H,"SISI") ;

  hoexpconssh(H)       =  HEXPCONS0(H) / SAM("TOTAL",H) ;

  YH0(H)         =  SAM(H,"TOTAL")  ;
  YR0(H)         =  SUM(HAOM(H,A),SAM(H,A)) + SUM(HAOM(H,A),SAM("FLAB",A))  ;
  YT0            =  SUM(H,YH0(H)) ;

*### Slack variables
  WALRAS0(H) = 0 ;

*### Parameters used in consumption demand functions

* Consumed commodities as in SAM
  QDT0("CAGR",H)     =  SAM("CAGR",H)/PD0("CAGR",H) ;
  QDT0("CPPLANT",H)  =  SAM("CPPLANT",H)/PD0("CPPLANT",H)  ;
  QDT0("CPANIM",H)   =  SAM("CPANIM",H)/PD0("CPANIM",H)  ;
  QDT0("CNONFOOD",H) =  SAM("CNONFOOD",H)/PD0("CNONFOOD",H)  ;
  QDT0("CSERVICES",H)=  SAM("CSERVICES",H)/PD0("CSERVICES",H)  ;
  QDT0("CLEIS",H)    =  SAM("FLAB",H)/PD0("CLEIS",H) ;

  QD0(C,H)           =  QDT0(C,H) / HS0(H) ;

  sigma(CD,H)        = (1-ielast(CD,H)/smax(CDD,ielast(CDD,H))) *  QD0(CD,H) ;
  gamma(C,H)$(CD(C)) = (PD0(C,H)*QD0(C,H) - PD0(C,H)*sigma(C,H)) /
                           (HEXPCP0(H)-sum(CDD,PD0(CDD,H)*sigma(CDD,H))) ;
* Purchases by households
  QP0(C,H)$(CP(C))  = QDT0(C,H) ;
* Sales of commodity c by households
  QS0(C,H)$(CQ(C))  = QQ0(C,H) - QDT0(C,H);

* Village imports and exports
  QVX0(C)$CVX(C)    =  SUM(H,QQ0(C,H)-QDT0(C,H)) ;
  QVM0(C)$CVM(C)    =  SUM(H,QDT0(C,H)) +  SUM(A,SUM(H,QINT0(A,C,H))) ;

*### Parameters associated with production and factor demand functions

* Production functions
  beta(F,A,H)$HAC(H,A) = FDC0(F,A,H)*WF0(F,H) /(SUM(FU,FDC0(FU,A,H)*WF0(FU,H))+SUM(FN,FDC0(FN,A,H)*WF0(FN,H))) ;
  alpha(A,H)$HAC(H,A)  = QVA0(A,H)/PROD(F,FDC0(F,A,H)**beta(F,A,H));

 Parameter factuse(F,H) "Total use of factor f by household h (used only for calibration)" ;

  factuse(F,"HLMHI") = SUM(HALMHI, FDC0(F,HALMHI,"HLMHI")) + SUM(HALMHI, FDD0(F,HALMHI,"HLMHI"));
  factuse(F,"HLMMD") = SUM(HALMMD, FDC0(F,HALMMD,"HLMMD")) + SUM(HALMMD, FDD0(F,HALMMD,"HLMMD"));
  factuse(F,"HLMLO") = SUM(HALMLO, FDC0(F,HALMLO,"HLMLO")) + SUM(HALMLO, FDD0(F,HALMLO,"HLMLO"));
  factuse(F,"HHMHI") = SUM(HAHMHI, FDC0(F,HAHMHI,"HHMHI")) + SUM(HAHMHI, FDD0(F,HAHMHI,"HHMHI"));
  factuse(F,"HHMMD") = SUM(HAHMMD, FDC0(F,HAHMMD,"HHMMD")) + SUM(HAHMMD, FDD0(F,HAHMMD,"HHMMD"));
  factuse(F,"HHMLO") = SUM(HAHMLO, FDC0(F,HAHMLO,"HHMLO")) + SUM(HAHMLO, FDD0(F,HAHMLO,"HHMLO"));

  ivash(A,H)$HAC(H,A)        = (QA0(A,H) - QINTA0(A,H))/ QA0(A,H) ;
*  ica(C,A,H)   ->  see above
  inta(A,H)$HAC(H,A)         =  QINTA0(A,H) / QA0(A,H) ;

*# 'Factor demand' - Labor

* Parameters for the 'factor demand function' for migration

* Given FDD and PA (above), kappa can be computed for each household
  kappa("HLMHI")   =  SAM("AMIGLMHI","OUTVILL") / (QQ0("CMIG","HLMHI")*PA0("AMIGLMHI","HLMHI")) ;
  kappa("HLMMD")   =  SAM("AMIGLMMD","OUTVILL") / (QQ0("CMIG","HLMMD")*PA0("AMIGLMMD","HLMMD")) ;
  kappa("HLMLO")   =  SAM("AMIGLMLO","OUTVILL") / (QQ0("CMIG","HLMLO")*PA0("AMIGLMLO","HLMLO")) ;
  kappa("HHMHI")   =  SAM("AMIGHMHI","OUTVILL") / (QQ0("CMIG","HHMHI")*PA0("AMIGHMHI","HHMHI")) ;
  kappa("HHMMD")   =  SAM("AMIGHMMD","OUTVILL") / (QQ0("CMIG","HHMMD")*PA0("AMIGHMMD","HHMMD")) ;
  kappa("HHMLO")   =  SAM("AMIGHMLO","OUTVILL") / (QQ0("CMIG","HHMLO")*PA0("AMIGHMLO","HHMLO")) ;

* With more than one household, the delta and epsilon are defined separately for each household in order to allow for a
* household specific calibration of the parameters.
* Currently, all delta(A,H) are chosen in a way that both households have the same migration wage elasticities of
* migration labor demand and of local off-farm labor demand.

*  delta(A,H) -> read from external data file
*  lambda(H)  -> read from external data file

  epsilon(AOM,H)$(FDD0("FLAB",AOM,H)) = ((kappa(H)*PA0(AOM,H) - WF0("FLAB",H) + pcscal(H)*SUM(CD,QD0(CD,H)*PD0(CD,H))) * lambda(H)) /
                      (delta(AOM,H)*FDD0("FLAB",AOM,H)**(delta(AOM,H)-1)) ;

* Parameters for the 'factor demand function' for formal and informal local off-farm labor

*  delta(A,H) -> read from external data file

  epsilon(AOL,H)$(FDD0("FLAB",AOL,H)) = ((PA0(AOL,H) - WF0("FLAB",H)) * lambda(H)) /
                      (delta(AOL,H)*FDD0("FLAB",AOL,H)**(delta(AOL,H)-1)) ;

  epsilon(A,H)$(NOT epsilon(A,H))  = NO ;

DISPLAY PA0, PVA0, PD0,
        PI0, PIA0,
        WF0, WFV0,
        hactive, hdeps, hdepscal, tp,
        kappa, ioqqqa,
        ielast, sigma, gamma,
        QD0, QDT0, QINT0, QINTA0, QA0, QVA0, QQ0, QR0, QRM0, QS0, QP0, QVM0, QVX0,
        FSH0, FSHM0, FDC0, FDD0,
        HEXPC0, HEXPCP0, HEXPCONS0,
        hexpgift, hexpshock, hexpsi,
        HS0,
        hoexpconssh,
        hobloodconst, hogiftconst, hogovconst, hoshoconst, hosiconst,
        YH0, YR0, YT0,
        WALRAS0,
        alpha, beta, factuse,
        ica, inta, ivash,
        lambda, delta, epsilon, pcscal
;

Parameter PCSUM(H) ;

 PCSUM(H) = pcscal(H)*SUM(CD,QD0(CD,H)*PD0(CD,H)) ;

Display PCSUM;

*############## 9. VARIABLE DECLARATION #####################################

*#### Exogenous variables #####################
* Exogenous variables are declared as variables and fixed below

 POSITIVE VARIABLES

  FSH(F,H)        Household endowment with factor f
  FSHM(F)         Endowment of migrated household with factor f
  PA(A,H)         Price of activity a to household h
  PD(C,H)         Consumer price of commodity c to household h
  PI(C,H)         Price of intermediate input c to household h
  PIA(A,H)        Aggregate intermediate input price of activity a of household h

*#### Endogenous variables #####################

 POSITIVE VARIABLES

  FDC(F,A,H)      Demand for factor f by CD activity a in household h
  FDD(F,A,H)      Demand for factor f by off-farm work activity a in household h
  HS(H)           Number of persons living in the household
  PVA(A,H)        Value added price of activity a of household h
  QA(A,H)         Output of activity a in household h
  QD(C,H)         Per capita demand of household h for commodity c
  QDT(C,H)        Total demand of household h for commodity c
  QINT(A,C,H)     Demand of activity a in household h for intermediate commodity c
  QINTA(A,H)      Aggregate demand of activity a in household h for intermediate commodity c
  QP(C,H)         Quantity of commodity purchased by household h
  QQ(C,H)         Quantity of commodity c produced by household h
  QS(C,H)         Quantity of commodity c sold by household h
  QVA(A,H)        Quantity of value added of C-D activity a of household h
  QVM(C)          Quantity of commodity c imported into the village
  QVX(C)          Quantity of commodity c exported out of the village
  WF(F,H)         Price for factor f in household h (shadow price if factor is nontraded)
  WFV             Village price of land
  HEXPCONS(H)     Expenditure of household h on construction
  HEXPC(H)        Consumption expenditure of household h
  HEXPCP(H)       Per-capita consumption expenditure of household h
  YH(H)           Total income of household h
  YHP(H)          Per capita income of household h
  YR(H)           Remittance income of household h

 FREE VARIABLES

  QR(C,H)         Net quantity of village traded commodity c rented by household h
  QRM(C)          Net quantity of village traded commodity c rented by migrated household
  WALRAS(H)       "Slack variable, one for each of the households' income constraints"
  YT              Total income of all households
 ;

*############## 10. VARIABLE INITIALISATION #####################################

*#### Exogenous variables #####################

  FSH.L(F,H)      = FSH0(F,H) ;
  FSHM.L(F)       = FSHM0(F) ;
  PA.L(A,H)       = PA0(A,H) ;
  PD.L(C,H)       = PD0(C,H) ;
  PI.L(C,H)       = PI0(C,H) ;

*#### Endogenous variables #####################

  FDC.L(F,A,H)    = FDC0(F,A,H) ;
  FDD.L(F,A,H)    = FDD0(F,A,H) ;
  HEXPC.L(H)      = HEXPC0(H) ;
  HEXPCONS.L(H)   = HEXPCONS0(H) ;
  HEXPCP.L(H)     = HEXPCP0(H) ;
  HS.L(H)         = HS0(H) ;
  PIA.L(A,H)      = PIA0(A,H) ;
  PVA.L(A,H)      = PVA0(A,H) ;
  QA.L(A,H)       = QA0(A,H) ;
  QD.L(C,H)       = QD0(C,H) ;
  QDT.L(C,H)      = QDT0(C,H) ;
  QINT.L(A,C,H)   = QINT0(A,C,H) ;
  QINTA.L(A,H)    = QINTA0(A,H) ;
  QP.L(C,H)       = QP0(C,H) ;
  QQ.L(C,H)       = QQ0(C,H) ;
  QR.L(C,H)       = QR0(C,H) ;
  QRM.L(C)        = QRM0(C) ;
  QS.L(C,H)       = QS0(C,H) ;
  QVA.L(A,H)      = QVA0(A,H) ;
  QVM.L(C)        = QVM0(C) ;
  QVX.L(C)        = QVX0(C) ;
  WF.L(F,H)       = WF0(F,H) ;
  WFV.L           = WFV0 ;
  WALRAS.L(H)     = WALRAS0(H) ;
  YH.L(H)         = YH0(H) ;
  YR.L(H)         = YR0(H) ;
  YT.L            = YT0 ;

*$ontext
 DISPLAY PA.L, PVA.L, PD.L, PI.L, PIA.L,
         WF.L,
         QD.L, QDT.L,  QINT.L, QINTA.L, QA.L, QVA.L, QQ.L, QR.L,  QS.L, QP.L, QVM.L, QVX.L,
         FSH.L, FDC.L, FDD.L,
         HEXPC.L, HEXPCP.L, HEXPCONS.L,
         HS.L,
         WALRAS.L,
         YH.L, YR.L, YT.L ;
*$offtext

*################# 11. EQUATIONS DECLARATION ############################

 EQUATIONS

*## PRICE BLOCK

   PLEIS(C,H)    Consumption price of leisure in household
   PLAND(F,H)    Price of land
   PVAHAC(A,H)   Value added price of activity a of household h
   PINTHAC(A,H)  Price of aggregate intermediate input of activity a of household h

*## PRODUCTION BLOCK

   INTDACD(A,H)   Aggregate intermediate input demand of C-D activities
   INTDCD(C,A,H)  Intermediate input demand of C-D activities
   VACD(A,H)      Value-added of C-D activity
   PRODCD(A,H)    Cobb-Douglas production function (agricultural production)
   PRODD(A,H)     Production function direct export activities (off-farm work)

   FDMIG(F,A,H)   Factor (labour) demand migration activities
   FDOFF(F,A,H)   Factor (labour) demand local off-farm activities
   FDCD(F,A,H)    Factor demand C-D activities

   COMOUT(C,H)    Commodity output

*## INCOME BLOCK

   REMIT(H)       Remittances function
   INCOME(H)      Total income of household h
   TOTINC         Total income of all households

*## EXPENDITURE BLOCK

   HHEEXPC(H)     Household consumption expenditure
   HHEXPCON(H)    Household expenditure on construction
   HHEXPSCAL(H)   Function to scale per capita consumption expenditure to total consumption expenditure
   QDEQ(C,H)      Household consumption demand
   CONSSCAL(C,H)  Function to scale per capita consumption to total household consumption

*## SYSTEM CONSTRAINTS
   HHCBAL(CM,H)   Household level commodity balance
   HMIGR(C)       Net land rentals of migrated household
   HHLBAL(F,H)    Household level land balance
   HHTCSTR(F,H)   Household time constraint
   HHICSTR(H)     Household income constraint
   HHSIZE(H)      Household size effective for consumption demand

   VILLCBAL1(CVX) Village level commodity balance exports
   VILLCBAL2(CVM) Village level commodity balance imports
   VILLLBAL(F)    Village level land balance
   VILLPBAL       Village balance of payments
 ;

*####################  12. EQUATIONS DEFINITION ############################

*## PRICE BLOCK

   PLEIS(C,H)$(CN(C))..                              PD(C,H) =E= WF("FLAB",H) ;
   PLAND(F,H)$(FN(F))..                              WF(F,H) =E= WFV ;
   PVAHAC(A,H)$HAC(H,A)..               PVA(A,H) * QVA(A,H)  =E= PA(A,H) * QA(A,H) - QINTA(A,H)*PIA(A,H)  ;
   PINTHAC(A,H)$HAC(H,A)..                          PIA(A,H) =E= SUM(C, PI(C,H) * ica(C,A,H)) ;

*## PRODUCTION BLOCK

*# Cobb-Douglas activities:

* Intermediate demand of C-D activities

  INTDACD(A,H)$inta(A,H)..                       QINTA(A,H) =E= inta(A,H) * QA(A,H) ;
  INTDCD(C,A,H)$(CI(C) AND ica(C,A,H))..        QINT(A,C,H) =E= ica(C,A,H) * QINTA(A,H) ;

* Value-added of C-D activities

  VACD(A,H)$(HAC(H,A))..                           QVA(A,H) =E= ivash(A,H) * QA(A,H) ;

* Output and factor demand of C-D activities

  PRODCD(A,H)$(HAC(H,A))..                       QVA(A,H)   =E= alpha(A,H) * PROD(F,FDC(F,A,H)**beta(F,A,H)) ;

  FDCD(F,A,H)$(HAC(H,A))..                       FDC(F,A,H) =E= (beta(F,A,H) * QVA(A,H) * PVA(A,H)) / WF(F,H) ;

*# Off-farm work activities

  PRODD(A,H)$(HAO(H,A) AND FDD0("FLAB",A,H))..     QA(A,H)  =E= SUM(F,FDD(F,A,H)) ;

  FDMIG(F,A,H)$(HAOM(H,A) AND FU(F))..     kappa(H)*PA(A,H) =E= WF(F,H) + 1/lambda(H) * epsilon(A,H) * delta(A,H)
                                                                 * FDD(F,A,H)**(delta(A,H)-1) - pcscal(H)*SUM(CD,QD(CD,H)*PD(CD,H)) ;

  FDOFF(F,A,H)$(HAOL(H,A) AND FU(F) AND FDD0(F,A,H)).. PA(A,H) =E= WF(F,H) + 1/lambda(H) * epsilon(A,H) * delta(A,H)
                                                                 * FDD(F,A,H)**(delta(A,H)-1) ;

  COMOUT(C,H)$(CQ(C) AND QQ0(C,H))..               QQ(C,H) =E= SUM(A, ioqqqa(A,C,H) * QA(A,H)) ;

*## INCOME BLOCK

  REMIT(H)..                                          YR(H) =E= kappa(H)*SUM(HAOM(H,A),PA(A,H)*QA(A,H)) ;

  INCOME(H)..                                         YH(H) =E= SUM(FU,SUM(HAC(H,A),(WF(FU,H)*FDC(FU,A,H))))
                                                                 + SUM(FU,SUM(HAOL(H,A),PA(A,H)*FDD(FU,A,H)))
                                                                 + YR(H)
                                                                 + SUM(CN,PD(CN,H)*QDT(CN,H))
                                                                 + SUM(FN,FSH(FN,H)*WF(FN,H))
                                                                 + hobloodconst(H) + hogiftconst(H) + hogovconst(H) + hoshoconst(H) + hosiconst(H)  ;

* Total income of all households

  TOTINC..                                               YT =E= SUM(H,YH(H)) ;

*## EXPENDITURE BLOCK

  HHEEXPC(H)..                                     HEXPC(H) =E= SUM(CD, QDT(CD,H) * PD(CD,H))  + WALRAS(H) ;

  HHEXPCON(H)..                                 HEXPCONS(H) =E= hoexpconssh(H) * YH(H) ;

  HHEXPSCAL(H)..                                   HEXPC(H) =E= HEXPCP(H) * HS(H) ;

  QDEQ(C,H)$(CD(C))..                               QD(C,H) =E= (PD(C,H)*sigma(C,H) + gamma(C,H)*(HEXPCP(H)-sum(CDD,PD(CDD,H)*sigma(CDD,H))))
                                                                 / PD(C,H) ;

  CONSSCAL(C,H)$(CD(C))..                           QDT(C,H)=E= QD(C,H) * HS(H) ;

*## SYSTEM CONSTRAINTS

*## Household level

* Commodity balances

   HHCBAL(CM,H)..                                  QQ(CM,H) + QP(CM,H) =E= QDT(CM,H) + QS(CM,H) ;

* Balance for land
* Note: Equation HMIGR also represents the village trade balance for land and QRM has to be fixed.

  HMIGR(C)$(CVNT(C))..                               QRM(C) =E= - SUM(H,QR(C,H)) ;
  HHLBAL(F,H)$(FN(F))..                            FSH(F,H) =E= SUM(HAC(H,A),FDC(F,A,H)) + QR("CLND",H)  ;

* Time constraint

  HHTCSTR(F,H)$(FU(F))..                           FSH(F,H) =E= SUM(HAC(H,A),FDC(F,A,H)) + SUM(HAO(H,A),FDD(F,A,H)) + QDT("CLEIS",H) ;

* Income constraint

  HHICSTR(H)..                                        YH(H) =E= HEXPC(H) + HEXPCONS(H) + hexpgift(H) + hexpshock(H) + hexpsi(H)  ;

* Household size effective for consumption demand (number of adult consumers in household)

  HHSIZE(H)..                                         HS(H) =E= hactive(H) - SUM(HAOM(H,A),FDD("FLAB",A,H))/tp + hdepscal * hdeps(H) ;

*## Village level

* Commodity balances

  VILLCBAL1(CVX)..                                 QVX(CVX) =E=  SUM(H,QQ(CVX,H)) - SUM(H,QDT(CVX,H)) ;
  VILLCBAL2(CVM)..                                 QVM(CVM) =E=  SUM(H,QP(CVM,H)) + SUM(A,SUM(H,QINT(A,CVM,H))) ;

*#################### 13. MODEL CLOSURE ####################

*## FIXED VARIABLES

*Factors

 FSH.FX(F,H) = FSH0(F,H) ;

*Prices

 PA.FX(A,H)  = PA0(A,H)  ;
 PD.FX(C,H)$(NOT CN(C)) = PD0(C,H)  ;
 PI.FX(C,H)$(CI(C))  = PI0(C,H)  ;

* Land market closure and land rentals
$ontext
Shifting from a model without a village land market to a model with land market requires three types of adjustments:
1. Change in the model structure: Add equation PLAND to the model (this means using model "V2243". Model "H2243" is the model without this equation)
2. Fix land rentals of the migrated household and make net land rentals of the other households flexible
3. Make WFV (the village land rental price) flexible
$offtext

* Closure for household model without land market (requires selection of Model "H2243" below)
*$ontext
 QR.FX(C,H) = QR0(C,H) ;
* QRM.FX(C) = QRM0(C) ;
 WFV.FX = 1 ;
*$offtext

* Closure for village CGE with land market (requires selection of Model "V2243" below)
$ontext
* QR.FX(C,H) = QR0(C,H) ;
 QRM.FX(C) = QRM0(C) ;
* WFV.FX = 1 ;
$offtext

*Fix all variables not in model at zero
 FDC.FX(F,A,H)$(NOT HAC(H,A)) = 0 ;
 FDD.FX(F,A,H)$(NOT HAO(H,A)) = 0 ;
 FDD.FX(F,A,H)$(NOT FDD0(F,A,H)) = 0 ;
 FDD.FX("FLND",A,H)           = 0 ;
 PA.FX(A,H)$(NOT PA0(A,H))    = 0 ;
 PI.FX(C,H)$(NOT CI(C))       = 0 ;
 PIA.FX(A,H)$(NOT HAC(H,A))   = 0 ;
 PVA.FX(A,H)$(NOT HAC(H,A))   = 0 ;
 QA.FX(A,H)$(NOT QA0(A,H))    = 0 ;
 QD.FX(C,H)$(NOT CD(C))       = 0 ;
 QDT.FX(C,H)$(NOT CD(C))      = 0 ;
 QINT.FX("AAGRLMHI",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX("AAGRLMMD",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX("AAGRLMLO",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX("AAGRHMHI",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX("AAGRHMMD",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX("AAGRHMLO",C,H)$(NOT CI(C)) = 0 ;
 QINT.FX(A,C,H)$(NOT HAC(H,A))= 0 ;
 QINTA.FX(A,H)$(NOT HAC(H,A)) = 0 ;
 QR.FX(C,H)$(NOT CVNT(C))     = 0 ;
 QRM.FX(C)$(NOT CVNT(C))      = 0 ;
 QS.FX(C,H)$(NOT CQ(C))       = 0 ;
 QS.FX(C,H)$(NOT QS0(C,H))    = 0 ;
 QP.FX(C,H)$(NOT CP(C))       = 0 ;
 QQ.FX(C,H)$(NOT CQ(C))       = 0 ;
 QQ.FX(C,H)$(NOT QQ0(C,H))    = 0 ;
 QVA.FX(A,H)$(NOT HAC(H,A))   = 0 ;
 QVM.FX(C)$(NOT CVM(C))       = 0 ;
 QVX.FX(C)$(NOT CVX(C))       = 0 ;

*######################## 14. MODEL & SOLVE STATEMENTS  ################

 MODEL H2243 the model without a village land market  /
  PLEIS, PVAHAC, PINTHAC,
  INTDACD, INTDCD, VACD, PRODCD, PRODD, FDMIG, FDOFF, FDCD, COMOUT,
  REMIT, INCOME, TOTINC,
  HHEEXPC, HHEXPCON, HHEXPSCAL,
  QDEQ, CONSSCAL,
  HHCBAL, HHLBAL, HHTCSTR, HHICSTR, HHSIZE,
  HMIGR,
  VILLCBAL1, VILLCBAL2
/ ;

 MODEL V2243 the model with a village land market  /
  PLEIS, PVAHAC, PINTHAC, PLAND,
  INTDACD, INTDCD, VACD, PRODCD, PRODD, FDMIG, FDOFF, FDCD, COMOUT,
  REMIT, INCOME, TOTINC,
  HHEEXPC, HHEXPCON, HHEXPSCAL,
  QDEQ, CONSSCAL,
  HHCBAL, HHLBAL, HHTCSTR, HHICSTR, HHSIZE,
  HMIGR,
  VILLCBAL1, VILLCBAL2
/ ;

 H2243.HOLDFIXED  = 1 ;
 H2243.TOLINFREP  = .0001 ;
 V2243.HOLDFIXED  = 1 ;
 V2243.TOLINFREP  = .0001 ;
* Select H2243 if closure for model without village land rental markets is selected above
 SOLVE H2243 USING NLP maximizing YT ;
* Select V2243 if closure for model with village FLND rental markets is selected above
* SOLVE V2243 USING NLP maximizing YT ;


*######################### 15. CALIBRATION CHECK ################
* Check calibration by comparing model solutions with calibrated values
$ontext
 PARAMETERS
  PAc(A,H)         Check activity price
  PVAc(A,H)        Check value-added price
  PDc(C,H)         Check consumer price
  PIc(C,H)         Check intermediate input price
  PIAc(A,H)        Check aggregate intermediate input price
  FDCc(F,A,H)      Check demand for factor f by CD activity a in household h
  FDDc(F,A,H)      Check demand for factor f by off-farm work activity a in household h
  HEXPCcc(H)       Check parameter household consumption expenditure
  HEXPCPc(H)       Check parameter per-capita household consumption expenditure
  QAc(A,H)         Check output of activity a in household h
  QDc(C,H)         Check per capita demand of household h for commodity c
  QDTc(C,H)        Check total demand of household h for commodity c
  QINTc(A,C,H)     Check demand of activity a in household h for intermediate commodity c
  QINTAc(A,H)      Check aggregate demand of activity a in household h for intermediate commodity c
  QPc(C,H)         Check quantity of commodity purchased by household h
  QQc(C,H)         Check quantity of commodity c produced by household h
  QSc(C,H)         Check quantity of commodity c sold by household h
  QRc(C,H)         Check quantity net rentals of commodity c by household h
  QRMc(C)          Check quantity net rentals of commodity c by migrated household
  QVAc(A,H)        Check quantity of value added of C-D activity a of household h
  QVMc(C)          Check quantity of village imports of commodity c
  QVXc(C)          Check quantity of village exports of commodity c
  Uc(H)            Check total utility of household h
  WFc(F,H)         Check price for factor f in household h (shadow price if factor is nontraded)
  WFVc             Check village land rental price
  YHc(H)           Check total income of household h
  YRc(H)           Check remittance income of household h
  YTc              Check total income of all households
  SUEPERCHK        Sum of all check parameters (must be zero!)
 ;

  PAc(A,H)      = PA.L(A,H) - PA0(A,H) ;
  PVAc(A,H)     = PVA.L(A,H) - PVA0(A,H) ;
  PDc(C,H)      = PD.L(C,H) - PD0(C,H) ;
  PIc(C,H)      = PI.L(C,H) - PI0(C,H) ;
  PIAc(A,H)     = PIA.L(A,H) - PIA0(A,H) ;
  FDCc(F,A,H)   = FDC.L(F,A,H) - FDC0(F,A,H) ;
  FDDc(F,A,H)   = FDD.L(F,A,H) - FDD0(F,A,H) ;
  HEXPCcc(H)    = HEXPC.L(H) - HEXPC0(H) ;
  HEXPCPc(H)    = HEXPCP.L(H) - HEXPCP0(H) ;
  QAc(A,H)      = QA.L(A,H) - QA0(A,H) ;
  QDc(C,H)      = QD.L(C,H) - QD0(C,H) ;
  QDTc(C,H)     = QDT.L(C,H) - QDT0(C,H) ;
  QINTc(A,C,H)  = QINT.L(A,C,H) - QINT0(A,C,H) ;
  QINTAc(A,H)   = QINTA.L(A,H) - QINTA0(A,H) ;
  QPc(C,H)      = QP.L(C,H) - QP0(C,H) ;
  QQc(C,H)      = QQ.L(C,H) - QQ0(C,H) ;
  QRc(C,H)      = QR.L(C,H) - QR0(C,H) ;
  QRMc(C)       = QRM.L(C)  - QRM0(C) ;
  QSc(C,H)      = QS.L(C,H) - QS0(C,H) ;
  QVAc(A,H)     = QVA.L(A,H) - QVA0(A,H) ;
  QVMc(C)       = QVM.L(C) - QVM0(C) ;
  QVXc(C)       = QVX.L(C) - QVX0(C) ;
  Uc(H)         = PROD(CD,(QD.L(CD,H) - sigma(CD,H))**gamma(CD,H) + SUM(HAO(H,A),(-epsilon(A,H) * FDD.L("FLAB",A,H)**delta(A,H))))
                  - PROD(CD,(QD.L(CD,H) - sigma(CD,H))**gamma(CD,H) + SUM(HAO(H,A),(-epsilon(A,H) * FDD0("FLAB",A,H)**delta(A,H)))) ;
  WFc(F,H)      = WF.L(F,H) - WF0(F,H) ;
  WFVc          = WFV.L - WFV0 ;
  YHc(H)        = YH.L(H) - YH0(H) ;
  YRc(H)        = YR.L(H) - YR0(H) ;
  YTc           = YT.L - YT0 ;
  SUEPERCHK     = SUM(A,SUM(H,PAc(A,H))) + SUM(C,SUM(H,PDc(C,H))) + SUM(C,SUM(H,PIc(C,H))) + SUM(A,SUM(H,PIAc(A,H))) + SUM(F,SUM(A,SUM(H,FDCc(F,A,H)))) +
                  SUM(F,SUM(A,SUM(H,FDDc(F,A,H)))) + SUM(A,SUM(H,QAc(A,H))) +
                  SUM(H,HEXPCcc(H)) + SUM(H,HEXPCPc(H)) +
                  SUM(A,SUM(H,QVAc(A,H))) + SUM(C,QVMc(C)) + SUM(C,QVXc(C)) + SUM(C,SUM(H,QDc(C,H))) + SUM(C,SUM(H,QDTc(C,H))) + SUM(C,SUM(H,QPc(C,H))) +
                  SUM(C,SUM(H,QQc(C,H))) + SUM(C,SUM(H,QSc(C,H))) + SUM(C,SUM(H,QRc(C,H))) + SUM(C,QRMc(C)) + SUM(A,SUM(C,SUM(H,QINTc(A,C,H)))) + SUM(A,SUM(H,QINTAc(A,H))) +
                  SUM(F,SUM(H,WFc(F,H))) + WFVc + SUM(H, YHc(H)) + SUM(H, YRc(H)) + YTc
 ;

 DISPLAY
  PA.L, PVA.L, PD.L, PI.L, PIA.L,
  FDC.L, FDD.L,
  HEXPC.L, HEXPCP.L,
  QA.L, QD.L, QDT.L, QINT.L, QINTA.L, QP.L, QQ.L, QR.L, QRM.L, QS.L, QVA.L, QVM.L, QVX.L,
  WF.L,  WFV.L,
  YH.L, YR.L, YT.L,
  PAc, PVAc, PDc, PIc, PIAc,
  FDCc, FDDc,
  HEXPCcc, HEXPCPc,
  QAc, QDc, QDTc, QINTc, QINTAc, QPc, QQc, QRc, QRMc, QSc, QVAc, QVMc, QVXc,
  Uc,
  WFc, WFVc,
  YHc, YRc, YTc,
  SUEPERCHK,
  WALRAS.L
 ;
$offtext

*######################### 16. POLICY SIMULATIONS ################

*##### To simulate the unilateral full liberalization trade policy scenario:
* For details, see include file.
$INCLUDE guimod1.01_sims_lib.inc






