$ontext
Copyright 2011 Ulrich Kleinwechter.

This file is part of Guimod 1.01.

Guimod is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

Guimod is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with Guimod.  If not, see <http://www.gnu.org/licenses/>.
$offtext


$ontext
This file serves to simulate a unilateral full liberalization scenario for China.
Price shocks and delta parameters are as in file "guimod1.01_scenario_lib.xls"
The scenario is taken from Zhai & Hertel (2010) and Zhai (2011) and described in
Kleinwechter (2011) (see reference in file "guimod1.01.gms").

For the scenario, five simulations are carried out:
 - Base (the base-run without a policy shock)
 - Full liberalization without village land rental market and equal migration responses
 - Full liberalization without village land rental market and different migration responses
 - Full liberalization with village land rental market and equal migration responses
 - Full liberalization with village land rental market and different migration responses
$offtext

*#### STRUCTURE #####
$ontext
1. SET DECLARATION
2. PARAMETER DECLARATION
3. DATA ENTRY
4. RUN SIMULATIONS
5. COLLECT RESULTS
6. DISPLAY RESULTS
7. EXPORT RESULTS
8. POVERTY AND INEQUALITY ANALYSIS
$offtext

*### 1. SET DECLARATION ###

*# Set up set for simulations
 SET  sim  Simulations ;

*# Set up additional household sets to collect results
 SET HLM(H)  Low migration households /
       hlmhi   Low migration high income household
       hlmmd   Low migration middle income household
       hlmlo   Low migration low income household /

     HHM(H)  High migration households /
       hhmhi   High migration high income household
       hhmmd   High migration middle income household
       hhmlo   High migration low income household /
     ALM(A) Activitites of low migration household /
       aagrlmhi
       aagrlmmd
       aagrlmlo
       aoffflmhi
       aoffflmmd
       aoffflmlo
       aoffilmhi
       aoffilmmd
       aoffilmlo
       amiglmhi
       amiglmmd
       amiglmlo  /
     AHM(A) Activitites of high migration household /
       aagrhmhi
       aagrhmmd
       aagrhmlo
       aofffhmhi
       aofffhmmd
       aofffhmlo
       aoffihmhi
       aoffihmmd
       aoffihmlo
       amighmhi
       amighmmd
       amighmlo  /
    ALMAG(A)   Agriculture of low migration household /
        aagrlmhi
       aagrlmmd
       aagrlmlo  /
     AHMAG(A)   Agriculture of high migration household /
       aagrhmhi
       aagrhmmd
       aagrhmlo  /
     ALMM(A)   Migration of low migration household /
       amiglmhi
       amiglmmd
       amiglmlo  /
     AHMM(A)   Migration of high migration household /
       amighmhi
       amighmmd
       amighmlo  /
     ALMOI(A)  Informal local off-farm work of low migration household /
       aoffilmhi
       aoffilmmd
       aoffilmlo    /
     AHMOI(A)  Informal local off-farm work of high migration household /
       aoffihmhi
       aoffihmmd
       aoffihmlo /
     ALMOF(A)  Formal local off-farm work of low migration household /
       aoffflmhi
       aoffflmmd
       aoffflmlo  /
     AHMOF(A)  Formal local off-farm work of high migration household /
       aofffhmhi
       aofffhmmd
       aofffhmlo /
;

*### 2. PARAMETER DECLARATION ###

*# Set up parameters to collect results

 PARAMETERS
  levPA(A,H,sim)         Level results activity prices
  levPD(C,H,sim)         Level results consumer price
  levFDC(F,A,H,sim)      Level results demand for factor f by CD activity a in household h
  levFDD(F,A,H,sim)      Level results demand for factor f by off-farm work activity a in household h
  levHEXPC(H,sim)        Level results household consumption expenditure
  levHEXPCP(H,sim)       Level results per capita household consumption expenditure
  levHEXPCONS(H,sim)     Level results household expenditure on construction
  levHS(H,sim)           Level results household size
  levQA(A,H,sim)         Level results output of activity a in household h
  levQD(C,H,sim)         Level results per capita demand of household h for commodity c
  levQDT(C,H,sim)        Level results total demand of household h for commodity c
  levQINT(A,C,H,sim)     Level results demand of activity a in household h for intermediate commodity c
  levQP(C,H,sim)         Level results quantity of commodity purchased by household h
  levQQ(C,H,sim)         Level results quantity of commodity c produced by household h
  levQR(C,H,sim)         Level results quantity of net land rentals by household h
  levQS(C,H,sim)         Level results quantity of commodity c sold by household h
  levQVA(A,H,sim)        Level results quantity of value added of C-D activity a of household h
  levQVM(C,sim)          Level results quantity of village imports of commodity c
  levQVX(C,sim)          Level results quantity of village exports of commodity c
  levWF(F,H,sim)         Level results price for factor f in household h (shadow price if factor is nontraded)
  levYH(H,sim)           Level results total income of household h
  levYHP(H,sim)          Level results per capita income of household h
  levYR(H,sim)           Level results remittance income of household h
* Additional results parameters to analyse the decrease in income from increase in migration wage
  levYA(H,sim)           Level results for income from productive acitivites (excludes leisure)
  levYAG(H,sim)          Level results for agricultural income
  levYAGL(H,sim)         Level results for income from labor in agriculture
  levYAGLN(H,sim)        Level results for income from land use
  levYAOF(H,sim)         Level results for income from local off-farm work
  levYAOFF(H,sim)        Level results for income from formal local off-farm work
  levYAOIF(H,sim)        Level results for income from informal local off-farm work
  levYL(H,sim)           Level results income from leisure
  levYT(sim)             Level results total village income
  levU(H,sim)            Level results total household utility
  levWALRAS(H,sim)       Level results for slack variable
* Additional result paramteres to collect results by migration group
  levFDCLM(F,sim)        Level results demand for factor f by CD activity low migration group
  levFDCHM(F,sim)        Level results demand for factor f by CD activity high migration group
  levFDCVIL(F,sim)       Level results demand for factor f by CD activity in village
  levFDMLM(F,sim)        Level results demand for labour by migration activity by low migration group
  levFDMHM(F,sim)        Level results demand for labour by migration activity by high migration group
  levFDMLOI(F,sim)       Level results demand for labour by informal local off-farm activity by low migration group
  levFDMHOI(F,sim)       Level results demand for labour by informal local off-farm activity by high migration group
  levFDMLOF(F,sim)       Level results demand for labour by formal local off-farm activity by low migration group
  levFDMHOF(F,sim)       Level results demand for labour by formal local off-farm activity by high migration group
  levQINTLM(C,sim)       Level results demand of activity a in low migration group for intermediate commodity c
  levQINTHM(C,sim)       Level results demand of activity a in high migration group for intermediate commodity c
  levQINTVIL(C,sim)      Level results demand of activity a in village for intermediate commodity c
  levQAALM(sim)          Level results agricultural output in low migration households
  levQAAHM(sim)          Level results agricultural output in high migration households
  levQAAVIL(sim)         Level results agricultural output in village
  levQSLM(C,sim)         Level results quantity of commodity c sold by low migration households
  levQSHM(C,sim)         Level results quantity of commodity c sold by high migration households
  levYHLM(sim)           Level results total income of low migration households
  levYHHM(sim)           Level results total income of high migration households
  levYRLM(sim)           Level results remittances income of low migration households
  levYRHM(sim)           Level results remittances income of high migration households
  levYRVIL(sim)          Level results remittances income of all households
  levYAGLM(sim)          Level results agricultural income of low migration households
  levYAGHM(sim)          Level results agriculturel income of high migration households
  levYAGVIL(sim)         Level results agricultural income of all households
  levYAOFFLM(sim)        Level results income from formal local off-farm work of low migration households
  levYAOFFHM(sim)        Level results income from formal local off-farm work of high migration households
  levYAOFFVIL(sim)       Level results income from formal local off-farm work of all households
  levYAOIFLM(sim)        Level results income from informal local off-farm work of low migration households
  levYAOIFHM(sim)        Level results income from informal local off-farm work of high migration households
  levYAOIFVIL(sim)       Level results income from informal local off-farm work of all households

  percPA(A,H,sim)         Percentage change results activity prices
  percPD(C,H,sim)         Percentage change results consumer price
  percFDC(F,A,H,sim)      Percentage change results demand for factor f by CD activity a in household h
  percFDD(F,A,H,sim)      Percentage change results demand for factor f by off-farm work activity a in household h
  percHEXPC(H,sim)        Percentage change results household consumption expenditure
  percHEXPCP(H,sim)       Percentage change results per capita household consumption expenditure
  percHEXPCONS(H,sim)     Percentage change results household expenditure on construction
  percHS(H,sim)           Percentage change results household size
  percQA(A,H,sim)         Percentage change results output of activity a in household h
  percQD(C,H,sim)         Percentage change results per capita demand of household h for commodity c
  percQDT(C,H,sim)        Percentage change results total demand of household h for commodity c
  percQINT(A,C,H,sim)     Percentage change results demand of activity a in household h for intermediate commodity c
  percQP(C,H,sim)         Percentage change results quantity of commodity purchased by household h
  percQQ(C,H,sim)         Percentage change results quantity of commodity c produced by household h
  percQR(C,H,sim)         Percentage change results quantity of net land rentals by household h
  percQS(C,H,sim)         Percentage change results quantity of commodity c sold by household h
  percQVA(A,H,sim)        Percentage change results quantity of value added of C-D activity a of household h
  percQVM(C,sim)          Percentage change results quantity of village imports of commodity c
  percQVX(C,sim)          Percentage change results quantity of village exports of commodity c
  percWF(F,H,sim)         Percentage change results price for factor f in household h (shadow price if factor is nontraded)
  percYH(H,sim)           Percentage change results total income of household h
  percYHP(H,sim)          Percentage change results per capita income of household h
  percYR(H,sim)           Percentage change results remittance income of household h
  percYA(H,sim)           Percentage change results for income from productive acitivites (excludes leisure)
  percYAG(H,sim)          Percentage change results for agricultural income
  percYAGL(H,sim)         Percentage change results for income from labor in agriculture
  percYAGLN(H,sim)        Percentage change results for income from land use
  percYAOF(H,sim)         Percentage change results for income from local off-farm work
  percYAOFF(H,sim)        Percentage change results for income from formal local off-farm work
  percYAOIF(H,sim)        Percentage change results for income from informal local off-farm work
  percYL(H,sim)           Percentage change results income from leisure
  percYT(sim)             Percentage change results total village income
* Additional result paramteres to collect results by migration group
  percFDCLM(F,sim)        Percentage change results demand for factor f by CD activity low migration group
  percFDCHM(F,sim)        Percentage change results demand for factor f by CD activity high migration group
  percFDCVIL(F,sim)       Percentage change results demand for factor f by CD activity in village
  percFDMLM(F,sim)        Percentage change results demand for labour by migration activity by low migration group
  percFDMHM(F,sim)        Percentage change results demand for labour by migration activity by high migration group
  percFDMLOI(F,sim)       Percentage change results demand for labour by informal local off-farm activity by low migration group
  percFDMHOI(F,sim)       Percentage change results demand for labour by informal local off-farm activity by high migration group
  percFDMLOF(F,sim)       Percentage change results demand for labour by formal local off-farm activity by low migration group
  percFDMHOF(F,sim)       Percentage change results demand for labour by formal local off-farm activity by high migration group
  percQINTLM(C,sim)       Percentage change results demand of activity a in low migration group for intermediate commodity c
  percQINTHM(C,sim)       Percentage change results demand of activity a in high migration group for intermediate commodity c
  percQINTVIL(C,sim)      Percentage change results demand of activity a in village for intermediate commodity c
  percQINTVILT(sim)       Percentage change results demand of activity a in village for all intermediate input commodities
  percQAALM(sim)          Percentage change results agricultural output in low migration households
  percQAAHM(sim)          Percentage change results agricultural output in high migration households
  percQAAVIL(sim)         Percentage change results agricultural output in village
  percQSLM(C,sim)         Percentage change results quantity of commodity c sold by low migration households
  percQSHM(C,sim)         Percentage change results quantity of commodity c sold by high migration households
  percYHLM(sim)           Percentage change results total income of low migration households
  percYHHM(sim)           Percentage change results total income of high migration households
  percYRLM(sim)           Percentage change results remittances income of low migration households
  percYRHM(sim)           Percentage change results remittances income of high migration households
  percYRVIL(sim)          Percentage change results remittances income of all households
  percYAGLM(sim)          Percentage change results agricultural income of low migration households
  percYAGHM(sim)          Percentage change results agricultural income of high migration households
  percYAGVIL(sim)         Percentage change results agricultural income of all households
  percYAOFFLM(sim)        Percentage change results income from formal local off-farm work of low migration households
  percYAOFFHM(sim)        Percentage change results income from formal local off-farm work of high migration households
  percYAOFFVIL(sim)       Percentage change results income from formal local off-farm work of all households
  percYAOIFLM(sim)        Percentage change results income from informal local off-farm work of low migration households
  percYAOIFHM(sim)        Percentage change results income from informal local off-farm work of high migration households
  percYAOIFVIL(sim)       Percentage change results income from informal local off-farm work of all households
* Welfare measures
  IC(H,sim)               Indirect compensation for household h
  EV(H,sim)               Equivalent variation for household h
  EVLM(sim)               Equivalent variation of low migration households
  EVHM(sim)               Equivalent variation of high migration households
  EVVIL(sim)              Equivalent variation of village
  EVperc(H,sim)           EV as percent of household consumption expenditure in baseline
  EVpercLM(sim)           EV as percent of household consumption expenditure in baseline low migration households
  EVpercHM(sim)           EV as percent of household consumption expenditure in baseline high migration households
  EVpercVIL(sim)          EV as percent of household consumption expenditure in baseline village level
 ;

*# Declare and assign parameters for simulations

 PARAMETERS

   PASIM(A,H,sim)     Simulation parameter for activity prices
   PDSIM(C,H,sim)     Simulation parameter for consumer prices
   PISIM(C,H,sim)     Simulation parameter for intermediate input prices
   pashock(A,H,sim)   Shock on activity prices in percentage terms
   pdshock(C,H,sim)   Shock on consumer prices in percentage terms
   pishock(C,H,sim)   Shock on intermediate input prices in percentage terms

   DELTSIM(A,H,sim)   Simulation parameter for deltas in off-farm labor demand functions

   CLOSELECT(sim)     Simulation parameter to select village market closure and version of model
 ;

*### 3. DATA ENTRY ###

*# Read in data for simulation sets and shocks

*# Convert data from xls to gdx
$CALL "GDXXRW i=guimod1.01_scenario_lib.xls o=data_shock_in.gdx index=Layout!A4"
$GDXIN data_shock_in.gdx

*# Read sets
$LOAD sim

*# Read shock parameters
$LOAD pashock, pdshock, pishock

*# Read delta parameters for simulations
$LOAD DELTSIM

*# Read parameter for selection of closure
$LOAD CLOSELECT

$GDXIN

* Define price shocks

   PASIM(A,H,sim)$HA(H,A) = PA0(A,H) * (1 + pashock(A,H,sim)/100) ;
   PDSIM(C,H,sim)$CP(C)   = PD0(C,H) * (1 + pdshock(C,H,sim)/100) ;
   PISIM(C,H,sim)$CI(C)   = PI0(C,H) * (1 + pishock(C,H,sim)/100) ;

DISPLAY sim,
        PASIM, PDSIM, PISIM,
        CLOSELECT,
        DELTSIM  ;

*### 4. RUN SIMULATIONS ###
*# Run the simulations

 LOOP(sim,

* Set price shocks
  PA.FX(A,H)$HA(H,A) =  PASIM(A,H,sim) ;
  PD.FX(C,H)$CP(C)   =  PDSIM(C,H,sim) ;
  PI.FX(C,H)$CI(C)   =  PISIM(C,H,sim) ;

* Set delta parameters and compute epsilon

  delta(A,H)$DELTSIM(A,H,sim)         = DELTSIM(A,H,sim) ;
  epsilon(AOM,H)$(FDD0("FLAB",AOM,H)) = ((kappa(H)*PA0(AOM,H) - WF0("FLAB",H) + pcscal(H)*SUM(CD,QD0(CD,H)*PD0(CD,H))) * lambda(H)) /
                      (delta(AOM,H)*FDD0("FLAB",AOM,H)**(delta(AOM,H)-1)) ;

  epsilon(AOL,H)$(FDD0("FLAB",AOL,H)) = ((PA0(AOL,H) - WF0("FLAB",H)) * lambda(H)) /
                      (delta(AOL,H)*FDD0("FLAB",AOL,H)**(delta(AOL,H)-1)) ;

  epsilon(A,H)$(NOT epsilon(A,H))     = NO ;

* Select closure and model and run experiments
  IF(CLOSELECT(sim) EQ 1,
         QR.FX(C,H) = QR0(C,H) ;
         WFV.FX = 0 ;
         SOLVE H2243 USING NLP maximizing YT ;
      );
  IF(CLOSELECT(sim) EQ 2,
         QR.UP(C,H)  = +inf ;
         QR.LO(C,H)  = -inf ;
         QRM.FX(C)   = QRM0(C) ;
         WFV.UP      = +inf ;
         WFV.LO      = -inf ;
         SOLVE V2243 USING NLP maximizing YT ;
     );

*### 5. COLLECT RESULTS ###

* Collect results
  levPA(A,H,sim)       =   PA.L(A,H) ;
  levPD(C,H,sim)       =   PD.L(C,H)   ;
  levFDC(F,A,H,sim)    =   FDC.L(F,A,H) ;
  levFDD(F,A,H,sim)    =   FDD.L(F,A,H) ;
  levHEXPC(H,sim)      =   HEXPC.L(H) ;
  levHEXPCP(H,sim)     =   HEXPCP.L(H) ;
  levHEXPCONS(H,sim)   =   HEXPCONS.L(H) ;
  levHS(H,sim)         =   HS.L(H) ;
  levQA(A,H,sim)       =   QA.L(A,H) ;
  levQD(C,H,sim)       =   QD.L(C,H) ;
  levQDT(C,H,sim)      =   QDT.L(C,H) ;
  levQINT(A,C,H,sim)   =   QINT.L(A,C,H) ;
  levQP(C,H,sim)       =   QP.L(C,H) ;
  levQQ(C,H,sim)       =   QQ.L(C,H) ;
  levQR(C,H,sim)       =   QR.L(C,H) ;
  levQS(C,H,sim)       =   QS.L(C,H) ;
  levQVA(A,H,sim)      =   QVA.L(A,H) ;
  levQVM(C,sim)        =   QVM.L(C) ;
  levQVX(C,sim)        =   QVX.L(C) ;
  levWF(F,H,sim)       =   WF.L(F,H) ;
  levYH(H,sim)         =   YH.L(H) ;
  levYHP(H,sim)        =   YH.L(H)/HS.L(H) ;
  levYR(H,sim)         =   YR.L(H) ;
* Additional results
  levYA(H,sim)        = SUM(FU,SUM(AC,(WF.L(FU,H)*FDC.L(FU,AC,H)))) + SUM(FU,SUM(AOL,PA.L(AOL,H)*FDD.L(FU,AOL,H))) + YR.L(H) + SUM(FN,FSH.L(FN,H)*WF.L(FN,H)) ;
  levYAG(H,sim)       = SUM(FU,SUM(AC,(WF.L(FU,H)*FDC.L(FU,AC,H))))+SUM(FN,FSH.L(FN,H)*WF.L(FN,H));
  levYAGL(H,sim)      = SUM(FU,SUM(AC,(WF.L(FU,H)*FDC.L(FU,AC,H))))    ;
  levYAGLN(H,sim)     = SUM(FN,SUM(A,FSH.L(FN,H)*WF.L(FN,H)))  ;
  levYAOF(H,sim)      = SUM(FU,SUM(AOL,PA.L(AOL,H)*FDD.L(FU,AOL,H)))  ;
  levYAOFF(H,sim)     = SUM(FU,SUM(AOF,PA.L(AOF,H)*FDD.L(FU,AOF,H)))  ;
  levYAOIF(H,sim)     = SUM(FU,SUM(AOI,PA.L(AOI,H)*FDD.L(FU,AOI,H)))  ;
  levYL(H,sim)        = SUM(CN,PD.L(CN,H)*QD.L(CN,H)) ;
  levYT(sim)          = YT.L ;
  levU(H,sim)         = PROD(CD,(sigma(CD,H))**gamma(CD,H) + SUM(AO,(-epsilon(AO,H)* FDD.L("FLAB",AO,H)**delta(AO,H)))) ;
  levWALRAS(H,sim)    = WALRAS.L(H) ;
  levFDCLM(F,sim)     = SUM(ALM,SUM(HLM,FDC.L(F,ALM,HLM))) ;
  levFDCHM(F,sim)     = SUM(AHM,SUM(HHM,FDC.L(F,AHM,HHM))) ;
  levFDCVIL(F,sim)    = levFDCLM(F,sim) + levFDCHM(F,sim) ;
  levFDMLM(F,sim)     = SUM(ALMM,SUM(HLM,FDD.L(F,ALMM,HLM))) ;
  levFDMHM(F,sim)     = SUM(AHMM,SUM(HHM,FDD.L(F,AHMM,HHM))) ;
  levFDMLOI(F,sim)    = SUM(ALMOI,SUM(HLM,FDD.L(F,ALMOI,HLM))) ;
  levFDMHOI(F,sim)    = SUM(AHMOI,SUM(HHM,FDD.L(F,AHMOI,HHM))) ;
  levFDMLOF(F,sim)    = SUM(ALMOF,SUM(HLM,FDD.L(F,ALMOF,HLM))) ;
  levFDMHOF(F,sim)    = SUM(AHMOF,SUM(HHM,FDD.L(F,AHMOF,HHM))) ;
  levQINTLM(C,sim)    = SUM(ALM,SUM(HLM,QINT.L(ALM,C,HLM))) ;
  levQINTHM(C,sim)    = SUM(AHM,SUM(HHM,QINT.L(AHM,C,HHM))) ;
  levQINTVIL(C,sim)   = levQINTLM(C,sim) +  levQINTHM(C,sim) ;
  levQAALM(sim)       = SUM(HLM, SUM(ALMAG, QA.L(ALMAG,HLM))) ;
  levQAAHM(sim)       = SUM(HHM, SUM(AHMAG, QA.L(AHMAG,HHM)));
  levQAAVIL(sim)      = levQAALM(sim) + levQAAHM(sim);
  levQSLM(C,sim)      = SUM(HLM,QS.L(C,HLM)) ;
  levQSHM(C,sim)      = SUM(HHM,QS.L(C,HHM)) ;
  levYHLM(sim)        = SUM(HLM,YH.L(HLM)) ;
  levYHHM(sim)        = SUM(HHM,YH.L(HHM)) ;
  levYRLM(sim)        = SUM(HLM,YR.L(HLM)) ;
  levYRHM(sim)        = SUM(HHM,YR.L(HHM)) ;
  levYRVIL(sim)       = levYRHM(sim) + levYRLM(sim) ;
  levYAGLM(sim)       = SUM(HLM,levYAG(HLM,sim)) ;
  levYAGHM(sim)       = SUM(HHM,levYAG(HHM,sim)) ;
  levYAGVIL(sim)      = levYAGHM(sim) + levYAGLM(sim) ;
  levYAOFFLM(sim)     = SUM(HLM,levYAOFF(HLM,sim)) ;
  levYAOFFHM(sim)     = SUM(HHM,levYAOFF(HHM,sim)) ;
  levYAOFFVIL(sim)    = levYAOFFHM(sim) + levYAOFFLM(sim) ;
  levYAOIFLM(sim)     = SUM(HLM,levYAOIF(HLM,sim)) ;
  levYAOIFHM(sim)     = SUM(HHM,levYAOIF(HHM,sim)) ;
  levYAOIFVIL(sim)    = levYAOIFHM(sim) + levYAOIFLM(sim) ;

  percPA(A,H,sim)$(PA0(A,H) ne 0)             =   (PA.L(A,H)/PA0(A,H)-1)*100 ;
  percPD(C,H,sim)$(PD0(C,H) ne 0)             =   (PD.L(C,H)/PD0(C,H)-1)*100 ;
  percFDC(F,A,H,sim)$(FDC0(F,A,H) ne 0)       =   (FDC.L(F,A,H)/FDC0(F,A,H)-1)*100 ;
  percFDD(F,A,H,sim)$(FDD0(F,A,H) ne 0)       =   (FDD.L(F,A,H)/FDD0(F,A,H)-1)*100 ;
  percHEXPC(H,sim)$(HEXPC0(H) ne 0)           =   (HEXPC.L(H)/HEXPC0(H)-1)*100 ;
  percHEXPCP(H,sim)$(HEXPCP0(H) ne 0)         =   (HEXPCP.L(H)/HEXPCP0(H)-1)*100 ;
  percHEXPCONS(H,sim)$(HEXPCONS0(H) ne 0)     =   (HEXPCONS.L(H)/HEXPCONS0(H)-1)*100 ;
  percHS(H,sim)$(HS0(H) ne 0)                 =   (HS.L(H)/HS0(H)-1)*100 ;
  percQA(A,H,sim)$(HA(H,A) AND QA0(A,H) ne 0) =   (QA.L(A,H)/QA0(A,H)-1)*100 ;
  percQD(C,H,sim)$(QD0(C,H) ne 0)             =   (QD.L(C,H)/QD0(C,H)-1)*100 ;
  percQDT(C,H,sim)$(QDT0(C,H) ne 0)           =   (QDT.L(C,H)/QDT0(C,H)-1)*100 ;
  percQINT(A,C,H,sim)$(QINT0(A,C,H) ne 0)     =   (QINT.L(A,C,H)/QINT0(A,C,H)-1)*100 ;
  percQP(C,H,sim)$(QP0(C,H) ne 0)             =   (QP.L(C,H)/QP0(C,H)-1)*100 ;
  percQQ(C,H,sim)$(QQ0(C,H) ne 0)             =   (QQ.L(C,H)/QQ0(C,H)-1)*100 ;
  percQR(C,H,sim)$(QR0(C,H)ne 0)              =   (QR.L(C,H)/QR0(C,H)-1)*100 ;
  percQS(C,H,sim)$(QS0(C,H) ne 0)             =   (QS.L(C,H)/QS0(C,H)-1)*100 ;
  percQVA(A,H,sim)$(QVA0(A,H) ne 0)           =   (QVA.L(A,H)/QVA0(A,H)-1)*100 ;
  percQVM(C,sim)$(QVM0(C) ne 0)               =   (QVM.L(C)/QVM0(C)-1)*100 ;
  percQVX(C,sim)$(QVX0(C) ne 0)               =   (QVX.L(C)/QVX0(C)-1)*100 ;
  percWF(F,H,sim)                             =   (WF.L(F,H)/WF0(F,H)-1)*100 ;
  percYH(H,sim)                               =   (YH.L(H)/YH0(H)-1)*100 ;
  percYHP(H,sim)                              =   ((YH.L(H)/HS.L(H)) / (YH0(H)/HS0(H)) -1)*100 ;
  percYR(H,sim)                               =   (YR.L(H)/YR0(H)-1)*100 ;
  percYA(H,sim)$(levYA(H,"base") ne 0)        =   (levYA(H,sim)/levYA(H,"base")-1)*100 ;
  percYAG(H,sim)$(levYAG(H,"base") ne 0)      =   (levYAG(H,sim)/levYAG(H,"base")-1)*100 ;
  percYAGL(H,sim)$(levYAGL(H,"base") ne 0)    =   (levYAGL(H,sim)/levYAGL(H,"base")-1)*100 ;
  percYAGLN(H,sim)$(levYAGLN(H,"base") ne 0)  =   (levYAGLN(H,sim)/levYAGLN(H,"base")-1)*100 ;
  percYAOF(H,sim)$(levYAOF(H,"base") ne 0)    =   (levYAOF(H,sim)/levYAOF(H,"base")-1)*100 ;
  percYAOFF(H,sim)$(levYAOFF(H,"base") ne 0)  =   (levYAOFF(H,sim)/levYAOFF(H,"base")-1)*100 ;
  percYAOIF(H,sim)$(levYAOIF(H,"base") ne 0)  =   (levYAOIF(H,sim)/levYAOIF(H,"base")-1)*100 ;
  percYL(H,sim)$(levYL(H,"base") ne 0)        =   (levYL(H,sim)/levYL(H,"base")-1)*100 ;
  percYT(sim)                                 =   (YT.L/YT0-1)*100 ;

  percFDCLM(F,sim)$(levFDCLM(F,"base") ne 0)  =   (levFDCLM(F,sim)/levFDCLM(F,"base")-1)*100 ;
  percFDCHM(F,sim)$(levFDCHM(F,"base") ne 0)  =   (levFDCHM(F,sim)/levFDCHM(F,"base")-1)*100 ;
  percFDCVIL(F,sim)$(levFDCVIL(F,"base") ne 0)=   (levFDCVIL(F,sim)/levFDCVIL(F,"base")-1)*100 ;
  percFDMLM(F,sim)$(levFDMLM(F,"base") ne 0)  =   (levFDMLM(F,sim)/levFDMLM(F,"base")-1)*100 ;
  percFDMHM(F,sim)$(levFDMHM(F,"base") ne 0)  =   (levFDMHM(F,sim)/levFDMHM(F,"base")-1)*100 ;
  percFDMLOI(F,sim)$(levFDMLOI(F,"base") ne 0)=   (levFDMLOI(F,sim)/levFDMLOI(F,"base")-1)*100 ;
  percFDMHOI(F,sim)$(levFDMHOI(F,"base") ne 0)=   (levFDMHOI(F,sim)/levFDMHOI(F,"base")-1)*100 ;
  percFDMLOF(F,sim)$(levFDMLOF(F,"base") ne 0)=   (levFDMLOF(F,sim)/levFDMLOF(F,"base")-1)*100 ;
  percFDMHOF(F,sim)$(levFDMHOF(F,"base") ne 0)=   (levFDMHOF(F,sim)/levFDMHOF(F,"base")-1)*100 ;
  percQINTLM(C,sim)$(levQINTLM(C,"base") ne 0)=   (levQINTLM(C,sim)/levQINTLM(C,"base")-1)*100 ;
  percQINTHM(C,sim)$(levQINTHM(C,"base") ne 0)=   (levQINTHM(C,sim)/levQINTHM(C,"base")-1)*100 ;
  percQINTVIL(C,sim)$(levQINTVIL(C,"base") ne 0)= (levQINTVIL(C,sim)/levQINTVIL(C,"base")-1)*100 ;
  percQINTVILT(sim)                           =   (SUM(C,levQINTVIL(C,sim))/SUM(C,levQINTVIL(C,"base"))-1)*100 ;
  percQAALM(sim)$(levQAALM("base") ne 0)      =   (levQAALM(sim)/levQAALM("base")-1)*100 ;
  percQAAHM(sim)$(levQAAHM("base") ne 0)      =   (levQAAHM(sim)/levQAAHM("base")-1)*100 ;
  percQAAVIL(sim)                             =   (levQAAVIL(sim)/levQAAVIL("base")-1)*100 ;
  percQSLM(C,sim)$(levQSLM(C,"base") ne 0)    =   (levQSLM(C,sim)/levQSLM(C,"base")-1)*100 ;
  percQSHM(C,sim)$(levQSHM(C,"base") ne 0)    =   (levQSHM(C,sim)/levQSHM(C,"base")-1)*100 ;
  percYHLM(sim)                               =   (levYHLM(sim)/levYHLM("base")-1)*100 ;
  percYHHM(sim)                               =   (levYHHM(sim)/levYHHM("base")-1)*100 ;
  percYRLM(sim)                               =   (levYRLM(sim)/levYRLM("base")-1)*100 ;
  percYRHM(sim)                               =   (levYRHM(sim)/levYRHM("base")-1)*100 ;
  percYRVIL(sim)                              =   (levYRVIL(sim)/levYRVIL("base")-1)*100 ;
  percYAGLM(sim)                              =   (levYAGLM(sim)/levYAGLM("base")-1)*100 ;
  percYAGHM(sim)                              =   (levYAGHM(sim)/levYAGHM("base")-1)*100 ;
  percYAGVIL(sim)                             =   (levYAGVIL(sim)/levYAGVIL("base")-1)*100 ;
  percYAOFFLM(sim)                            =   (levYAOFFLM(sim)/levYAOFFLM("base")-1)*100 ;
  percYAOFFHM(sim)                            =   (levYAOFFHM(sim)/levYAOFFHM("base")-1)*100 ;
  percYAOFFVIL(sim)                           =   (levYAOFFVIL(sim)/levYAOFFVIL("base")-1)*100 ;
  percYAOIFLM(sim)                            =   (levYAOIFLM(sim)/levYAOIFLM("base")-1)*100 ;
  percYAOIFHM(sim)                            =   (levYAOIFHM(sim)/levYAOIFHM("base")-1)*100 ;
  percYAOIFVIL(sim)                           =   (levYAOIFVIL(sim)/levYAOIFVIL("base")-1)*100 ;

  IC(H,sim)                                   =  (((HEXPCP.L(H) - SUM(CD,PD.L(CD,H)*sigma(CD,H)))
                                                   / (PROD(CD,PD.L(CD,H)**gamma(CD,H))))
                                                   * (PROD(CD,PD0(CD,H)**gamma(CD,H)))
                                                   + SUM(CD,PD0(CD,H)*sigma(CD,H)))*1000 ;
  EV(H,sim)                                   =  IC(H,sim) - HEXPCP0(H)*1000 ;
  EVLM(sim)                                   = SUM(HLM,EV(HLM,sim)) ;
  EVHM(sim)                                   = SUM(HHM,EV(HHM,sim)) ;
  EVVIL(sim)                                  = SUM(H,EV(H,sim));
  EVperc(H,sim)                               = EV(H,sim)/(levHEXPCP(H,"base")*1000) *100;
  EVpercLM(sim)                               = EVLM(sim)/(SUM(HLM,levHEXPCP(HLM,"base"))*1000) *100;
  EVpercHM(sim)                               = EVHM(sim)/(SUM(HHM,levHEXPCP(HHM,"base"))*1000) *100;
  EVpercVIL(sim)                              = EVVIL(sim)/(SUM(H,levHEXPCP(H,"base"))*1000) *100;
   ) ;

*### 6. DISPLAY RESULTS ###
*$ontext
 DISPLAY
  levPA, levPD,
  levFDC, levFDD,
  levHEXPC, levHEXPCP, levHEXPCONS,
  levHS,
  levQA, levQD, levQDT, levQINT, levQP, levQQ, levQR, levQS, levQVA, levQVM, levQVX,
  levWF,
  levYH, levYHP, levYR,
  levYA, levYAG, levYAGL, levYAGLN, levYAOF, levYAOFF, levYAOIF, levYL,
  levYT,
  levU,
  levWALRAS,
  levFDCLM, levFDCHM, levFDCVIL, levFDMLM, levFDMHM, levFDMLOI, levFDMHOI, levFDMLOF,  levFDMHOF,  levQINTLM, levQINTHM, levQINTVIL,
  levQAALM, levQAAHM, levQAAVIL, levQSLM, levQSHM,
  levYHLM, levYHHM, levYRLM, levYRHM, levYRVIL, levYAGLM, levYAGHM, levYAGVIL, levYAOFFLM, levYAOFFHM, levYAOFFVIL, levYAOIFLM, levYAOIFHM, levYAOIFVIL,

  IC, EV, EVLM, EVHM, EVVIL, EVperc, EVpercLM, EVpercHM, EVpercVIL,

  percPA, percPD,
  percFDC, percFDD,
  percHEXPC, percHEXPCP, percHEXPCONS,
  percHS,
  percQA, percQD, percQDT, percQINT, percQP, percQQ, percQR, percQS, percQVA, percQVM, percQVX,
  percWF,
  percYH, percYHP, percYR,
  percYA, percYAG, percYAGL, percYAGLN, percYAOF, percYAOFF, percYAOIF, percYL,
  percYT,
  percFDCLM, percFDCHM, percFDCVIL, percFDMLM, percFDMHM, percFDMLOI, percFDMHOI, percFDMLOF,  percFDMHOF,  percQINTLM, percQINTHM, percQINTVIL, percQINTVILT,
  percQAALM, percQAAHM, percQAAVIL, percQSLM, percQSHM,
  percYHLM, percYHHM, percYRLM, percYRHM, percYRVIL, percYAGLM, percYAGHM, percYAGVIL, percYAOFFLM, percYAOFFHM, percYAOFFVIL, percYAOIFLM, percYAOIFHM, percYAOIFVIL
;
*$offtext

*### 7. EXPORT RESULTS ###

*# Export results to gdx file:
*$ontext
 Execute_unload 'guimod1.01_res_sims_lib.gdx',
  levPA, levPD,
  levFDC, levFDD,
  levHEXPC, levHEXPCP, levHEXPCONS,
  levHS,
  levQA, levQD, levQDT, levQINT, levQP, levQQ, levQR, levQS, levQVA, levQVM, levQVX,
  levWF,
  levYH, levYHP, levYR,
  levYA, levYAG, levYAGL, levYAGLN, levYAOF, levYAOFF, levYAOIF, levYL,
  levYT,
  levU,
  levWALRAS,
  levFDCLM, levFDCHM, levFDCVIL, levFDMLM, levFDMHM, levFDMLOI, levFDMHOI, levFDMLOF,  levFDMHOF,  levQINTLM, levQINTHM, levQINTVIL,
  levQAALM, levQAAHM, levQAAVIL, levQSLM, levQSHM,
  levYHLM, levYHHM, levYRLM, levYRHM, levYRVIL, levYAGLM, levYAGHM, levYAGVIL, levYAOFFLM, levYAOFFHM, levYAOFFVIL, levYAOIFLM, levYAOIFHM, levYAOIFVIL,

  IC, EV, EVLM, EVHM, EVVIL, EVperc, EVpercLM, EVpercHM, EVpercVIL,

  percPA, percPD,
  percFDC, percFDD,
  percHEXPC, percHEXPCP, percHEXPCONS,
  percHS,
  percQA, percQD, percQDT, percQINT, percQP, percQQ, percQR, percQS, percQVA, percQVM, percQVX,
  percWF,
  percYH, percYHP, percYR,
  percYA, percYAG, percYAGL, percYAGLN, percYAOF, percYAOFF, percYAOIF, percYL,
  percYT,
  percFDCLM, percFDCHM, percFDCVIL, percFDMLM, percFDMHM, percFDMLOI, percFDMHOI, percFDMLOF,  percFDMHOF,  percQINTLM, percQINTHM, percQINTVIL, percQINTVILT,
  percQAALM, percQAAHM, percQAAVIL, percQSLM, percQSHM,
  percYHLM, percYHHM, percYRLM, percYRHM, percYRVIL, percYAGLM, percYAGHM, percYAGVIL, percYAOFFLM, percYAOFFHM, percYAOFFVIL, percYAOIFLM, percYAOIFHM, percYAOIFVIL
;
*$offtext

*# Export results to xls file
* Uncomment below to write results to xls
*$INCLUDE guimod1.01_sims_lib_xlsexport.inc

*### 8. POVERTY AND INEQUALITY ANALYSIS ###

* Uncomment below to export results for poverty analysis to 'guimod1.0_incchange_sims_lib.xls'
* which will be used by the R script 'povanalysis.r'.
* It requires the %change in income and %change in household size as data input.
*$INCLUDE guimod1.01_sims_lib_povanaly.inc

